import { Discussions, Discussion, UserFilter, Users, User } from "./types";
import { FlarumApi } from "./flarum";
export declare class FlarumUsers {
    /**
     * @description get all users
     * @param userNameOrUserId if authorizing with api key, pass the user ID, otherwise pass the username
     * @param passwordOrApiToken if authorizing with the api key, pass api key, otherwise pass the password.
     * @returns string for error and undefined in case of success
     */
    static getAll: (api: FlarumApi, filter?: UserFilter) => Promise<string | Users>;
    static getNext: (api: FlarumApi, discussions: Discussions) => Promise<string | Users>;
    static getPrev: (api: FlarumApi, discussions: Discussions) => Promise<string | Users>;
    /**
     * Create a new discussion
     * POST /api/discussions
     * @param api
     * @param discussion
     */
    static create: (api: FlarumApi, user: User) => Promise<string | User>;
    /**
     * @description Get information about the forum, including groups and tags
     */
    static get: (api: FlarumApi, id: number) => Promise<string | User>;
    /**
     * PATCH /api/discussions/:id - update the discussion
     * @param api
     * @param id
     * @returns
     */
    static update: (api: FlarumApi, id: number, data: Discussion) => Promise<string | undefined>;
    /**
     * @description Update forum config
     */
    static delete: (api: FlarumApi, id: number) => Promise<undefined | string>;
}
